{{ header }}

.. _api.options:

====================
Options and settings
====================
.. currentmodule:: pandas

API for configuring global behavior. See :ref:`the User Guide <options>` for more.

Working with options
--------------------
.. autosummary::
   :toctree: api/

   describe_option
   reset_option
   get_option
   set_option
   option_context

Numeric formatting
------------------
.. autosummary::
   :toctree: api/

   set_eng_float_format
